@@ -3,6 +3,9 @@ wlcm <- paste0("\n",
                "--------------------------------------------------------------------------------\n",
                "Welcome to augmentedRCBD version ", utils::packageDescription("augmentedRCBD")$Version, "\n",
                "\n", "\n",
+               "# To know how to use this package type:", "\n",
+               "  browseVignettes(package = 'augmentedRCBD')", "\n", "  for the package vignette.", "\n",
+               "\n",
                "# To know whats new in this version type:", "\n",
                "  news(package='augmentedRCBD')", "\n", "  for the NEWS file.", "\n",
                "\n",
